@@ -286,8 +286,7 @@ def _basic_authorization(credentials: dict = None):
         set_status(401)
         set_header("WWW-Authenticate", "Basic")
         return False
-    authorization = _HEADERS["Authorization"].split("Basic ")[-1]
-    u, p = b64d_and_utf8d(authorization).split(":")
+    u, p = parse_authorization()
     if u in credentials and credentials[u] == p:
         return True
     set_status(401)
@@ -295,6 +294,14 @@ def _basic_authorization(credentials: dict = None):
     return False
 
 
+def parse_authorization():
+    if "Authorization" in _HEADERS:
+        authorization = _HEADERS["Authorization"].split("Basic ")[-1]
+        return b64d_and_utf8d(authorization).split(":")
+    else:
+        return []
+
+
 def execute(
         method: str = "get", cacheable: bool = False,
         cache_ctrl = _cache_control,
